Changelog
=========

0.1.5 (2014-09-11)
------------------
#. Introduced support for Django 1.7.

0.1.4 (2013-06-21)
------------------
#. South patches the test management command to handle the SOUTH_TESTS_MIGRATE setting. Apply that patch if South is installed.

0.1.3 (2013-05-23)
------------------
#. Python 3 compatibility.

0.1.2 (2012-07-02)
------------------
#. Exclude South migrations from Pep8.

0.1.1 (2012-06-19)
------------------
#. Corrections to support PEP8 backwards incompatible API update.

0.0.9 (2012-06-15)
------------------
#. Now supports running specific test classes or methods via the label option.

0.0.8 (2012-06-13)
------------------
#. Added autoreload option restarting testrunner on code change detection.

0.0.7 (2012-06-04)
------------------
#. Refactor into a test command allowing for failfast commandline argument.

0.0.6 (2011-09-08)
------------------
#. Refactor, cleanup, self contained suite class.

0.0.5 (2011-09-06)
------------------
#. Added frame hack to resolve packages and py_modules to test, no longer needs app specific test suite.

0.0.4 (2011-09-06)
------------------
#. Refactored the app to use a callback style approach instead of monkey patching. Thanks `jezdez <https://github.com/jezdez>`_.

0.0.3 (2011-08-30)
------------------
#. More robust test settings import.

0.0.2 (2011-08-29)
------------------
#. Repeat Pep 8 errors.

0.0.1 (2011-08-29)
------------------
#. Initial release.

